|  | PAGENUMBER
PART I |
Item 1. | Business | 6
Item 1A. | Risk Factors | 22
Item 1B. | Unresolved Staff Comments | 46
Item 2. | Properties | 46
Item 3. | Legal Proceedings | 47
Item 4. | Mine Safety Disclosures | 51
PART II |  |
Item 5. | Market for Registrant's Common Equity, Related Stockholder Matters and Issuer Purchases of Equity Securities | 52
Item 6. | Selected Financial Data | 54
Item 7. | Management's Discussion and Analysis of Financial Condition and Results of Operations | 56
Item 7A. | Quantitative and Qualitative Disclosures About Market Risk | 83
Item 8. | Financial Statements and Supplementary Data | 86
Item 9. | Changes in and Disagreements With Accountants on Accounting and Financial Disclosure | 152
Item 9A. | Controls and Procedures | 152
Item 9B. | Other Information | 152
PART III |  |
Item 10. | Directors, Executive Officers and Corporate Governance | 153
Item 11. | Executive Compensation | 153
Item 12. | Security Ownership of Certain Beneficial Owners and Management and Related Stockholder Matters | 153
Item 13. | Certain Relationships and Related Transactions, and Director Independence | 153
Item 14. | Principal Accounting Fees and Services | 153
PART IV |  |
Item 15. | Exhibits, Financial Statement Schedules | 154